@@ -135,9 +135,7 @@ static void       xfwm_settings_title_button_drag_data               (GtkWidget
                                                                       GdkDragContext       *drag_context,
                                                                       GtkSelectionData     *data,
                                                                       guint                 info,
-                                                                      guint                 time,
-                                                                      const gchar          *atom_name,
-                                                                      XfwmSettings         *settings);
+                                                                      guint                 time);
 static void       xfwm_settings_title_button_drag_begin              (GtkWidget            *widget,
                                                                       GdkDragContext       *drag_context);
 static void       xfwm_settings_title_button_drag_end                (GtkWidget            *widget,
@@ -207,6 +205,13 @@ struct _ShortcutTemplate
   const gchar *shortcut;
 };
 
+enum
+{
+  COL_THEME_NAME,
+  COL_THEME_RC,
+  N_COLUMNS
+};
+
 
 
 static GObjectClass      *xfwm_settings_parent_class = NULL;
@@ -335,25 +340,6 @@ xfwm_settings_get_type (void)
 }
 
 
-/*
- * Xfce 4.6 depends on glib 2.12,
- * Glib 2.14 comes with g_hash_table_get_keys(),
- * until then... use the following function with
- * g_hash_table_foreach()
- */
-#if !GLIB_CHECK_VERSION (2,14,0)
-static void
-xfwm4_settings_get_list_keys_foreach (gpointer key,
-                                      gpointer value,
-                                      gpointer user_data)
-{
-  GList **keys = user_data;
-  *keys = g_list_prepend (*keys, key);
-}
-#endif
-
-
-
 
 static void
 xfwm_settings_class_init (XfwmSettingsClass *klass)
@@ -448,12 +434,13 @@ xfwm_settings_constructed (GObject *object)
 
   /* Style tab: theme name */
   {
-    list_store = gtk_list_store_new (1, G_TYPE_STRING);
-    gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (list_store), 0,
+    list_store = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING);
+    gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (list_store), COL_THEME_NAME,
                                      (GtkTreeIterCompareFunc) xfwm_settings_theme_sort_func,
                                      NULL, NULL);
-    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list_store), 0, GTK_SORT_ASCENDING);
+    gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (list_store), COL_THEME_NAME, GTK_SORT_ASCENDING);
     gtk_tree_view_set_model (GTK_TREE_VIEW (theme_name_treeview), GTK_TREE_MODEL (list_store));
+    g_object_unref (G_OBJECT (list_store));
 
     renderer = gtk_cell_renderer_text_new ();
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (theme_name_treeview),
@@ -485,9 +472,9 @@ xfwm_settings_constructed (GObject *object)
     for (template = title_align_values; template->name != NULL; ++template)
       {
         gtk_list_store_append (list_store, &iter);
-        gtk_list_store_set (list_store, &iter, 0, template->name, 1, template->value, -1);
+        gtk_list_store_set (list_store, &iter, 0, _(template->name), 1, template->value, -1);
       }
-
+    g_object_unref (G_OBJECT (list_store));
     xfconf_channel_get_property (settings->priv->wm_channel, "/general/title_alignment", &value);
     xfwm_settings_title_alignment_property_changed (settings->priv->wm_channel,
                                                     "/general/title_alignment", &value, settings);
@@ -502,11 +489,11 @@ xfwm_settings_constructed (GObject *object)
   /* Style tab: button layout */
   {
     target_entry[0].target = "_xfwm4_button_layout";
-    target_entry[0].flags = GTK_TARGET_SAME_APP;
+    target_entry[0].flags = 0;
     target_entry[0].info = 2;
 
     target_entry[1].target = "_xfwm4_active_layout";
-    target_entry[1].flags = GTK_TARGET_SAME_APP;
+    target_entry[1].flags = 0;
     target_entry[1].info = 3;
 
     gtk_drag_dest_set (active_frame, GTK_DEST_DEFAULT_ALL, target_entry, 2, GDK_ACTION_MOVE);
@@ -541,8 +528,7 @@ xfwm_settings_constructed (GObject *object)
         gtk_drag_source_set (button, GDK_BUTTON1_MASK, &target_entry[1], 1, GDK_ACTION_MOVE);
 
         g_signal_connect (button, "drag_data_get",
-                          G_CALLBACK (xfwm_settings_title_button_drag_data),
-                          target_entry[1].target);
+                          G_CALLBACK (xfwm_settings_title_button_drag_data), NULL);
         g_signal_connect (button, "drag_begin", G_CALLBACK (xfwm_settings_title_button_drag_begin),
                           NULL);
         g_signal_connect (button, "drag_end", G_CALLBACK (xfwm_settings_title_button_drag_end),
@@ -566,8 +552,7 @@ xfwm_settings_constructed (GObject *object)
       gtk_drag_source_set (button, GDK_BUTTON1_MASK, &target_entry[0], 1, GDK_ACTION_MOVE);
 
         g_signal_connect (button, "drag_data_get",
-                          G_CALLBACK (xfwm_settings_title_button_drag_data),
-                          target_entry[1].target);
+                          G_CALLBACK (xfwm_settings_title_button_drag_data), NULL);
         g_signal_connect (button, "drag_begin", G_CALLBACK (xfwm_settings_title_button_drag_begin),
                           NULL);
         g_signal_connect (button, "drag_end", G_CALLBACK (xfwm_settings_title_button_drag_end),
@@ -604,6 +589,7 @@ xfwm_settings_constructed (GObject *object)
 
     list_store = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
     gtk_tree_view_set_model (GTK_TREE_VIEW (shortcuts_treeview), GTK_TREE_MODEL (list_store));
+    g_object_unref (G_OBJECT (list_store));
 
     renderer = gtk_cell_renderer_text_new ();
     gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (shortcuts_treeview),
@@ -644,11 +630,11 @@ xfwm_settings_constructed (GObject *object)
   xfconf_g_property_bind (settings->priv->wm_channel, "/general/click_to_focus", G_TYPE_BOOLEAN,
                           click_to_focus_radio, "active");
 
-  g_signal_connect (settings->priv->wm_channel, "property-changed::/general/click_to_focus", 
+  g_signal_connect (settings->priv->wm_channel, "property-changed::/general/click_to_focus",
                     G_CALLBACK (xfwm_settings_click_to_focus_property_changed), settings);
-  
+
   xfconf_channel_get_property (settings->priv->wm_channel, "/general/click_to_focus", &value);
-  xfwm_settings_click_to_focus_property_changed (settings->priv->wm_channel, 
+  xfwm_settings_click_to_focus_property_changed (settings->priv->wm_channel,
                                                  "/general/click_to_focus", &value, settings);
   g_value_unset (&value);
 
@@ -682,9 +668,9 @@ xfwm_settings_constructed (GObject *object)
     for (template = double_click_values; template->name != NULL; ++template)
       {
         gtk_list_store_append (list_store, &iter);
-        gtk_list_store_set (list_store, &iter, 0, template->name, 1, template->value, -1);
+        gtk_list_store_set (list_store, &iter, 0, _(template->name), 1, template->value, -1);
       }
-
+    g_object_unref (G_OBJECT (list_store));
     xfconf_channel_get_property (settings->priv->wm_channel, "/general/double_click_action",
                                  &value);
     xfwm_settings_double_click_action_property_changed (settings->priv->wm_channel,
@@ -808,7 +794,6 @@ xfwm_settings_new (void)
 }
 
 
-
 static gint
 xfwm_settings_theme_sort_func (GtkTreeModel *model,
                                GtkTreeIter  *iter1,
@@ -841,8 +826,6 @@ xfwm_settings_load_themes (XfwmSettings *settings)
   GtkTreeIter   iter;
   GtkWidget    *view;
   GHashTable   *themes;
-  GList        *keys;
-  GList        *key;
   GDir         *dir;
   const gchar  *file;
   gchar       **theme_dirs;
@@ -859,6 +842,8 @@ xfwm_settings_load_themes (XfwmSettings *settings)
   theme_dirs = xfce_resource_dirs (XFCE_RESOURCE_THEMES);
   xfce_resource_pop_path (XFCE_RESOURCE_THEMES);
 
+  active_theme_name = xfconf_channel_get_string (settings->priv->wm_channel, "/general/theme", DEFAULT_THEME);
+
   for (i = 0; theme_dirs[i] != NULL; ++i)
     {
       dir = g_dir_open (theme_dirs[i], 0, NULL);
@@ -870,10 +855,24 @@ xfwm_settings_load_themes (XfwmSettings *settings)
         {
           filename = g_build_filename (theme_dirs[i], file, "xfwm4", "themerc", NULL);
 
+          /* check if the theme rc exists and there is not already a theme with the
+           * same name in the database */
           if (g_file_test (filename, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR) &&
               g_hash_table_lookup (themes, file) == NULL)
             {
               g_hash_table_insert (themes, g_strdup (file), GINT_TO_POINTER (1));
+
+              /* insert in the list store */
+              gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+              gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+                                  COL_THEME_NAME, file,
+                                  COL_THEME_RC, filename, -1);
+
+              if (G_UNLIKELY (g_str_equal (active_theme_name, file)))
+                {
+                  gtk_tree_selection_select_iter (gtk_tree_view_get_selection (GTK_TREE_VIEW (view)),
+                                                  &iter);
+                }
             }
 
           g_free (filename);
@@ -882,31 +881,9 @@ xfwm_settings_load_themes (XfwmSettings *settings)
       g_dir_close (dir);
     }
 
-  active_theme_name = xfconf_channel_get_string (settings->priv->wm_channel, "/general/theme", DEFAULT_THEME);
-
-  keys = NULL;
-#if !GLIB_CHECK_VERSION (2,14,0)
-  g_hash_table_foreach (themes, xfwm4_settings_get_list_keys_foreach, &keys);
-#else
-  keys = g_hash_table_get_keys (themes);
-#endif
-
-  for (key = keys; key != NULL; key = g_list_next (key))
-    {
-      gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-      gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, g_strdup (key->data), -1);
-
-      if (G_UNLIKELY (g_str_equal (active_theme_name, key->data)))
-        {
-          gtk_tree_selection_select_iter (gtk_tree_view_get_selection (GTK_TREE_VIEW (view)),
-                                          &iter);
-        }
-    }
-
-  g_list_free (keys);
   g_free (active_theme_name);
-  g_hash_table_unref (themes);
   g_strfreev (theme_dirs);
+  g_hash_table_destroy (themes);
 }
 
 
@@ -1022,22 +999,40 @@ xfwm_settings_theme_selection_changed (GtkTreeSelection *selection,
 {
   GtkTreeModel *model;
   GtkTreeIter   iter;
-  GList        *rows;
-  gchar        *theme;
+  gchar        *theme, *filename;
+  XfceRc       *rc;
+  GtkWidget    *widget;
+  gboolean      button_layout = FALSE;
+  gboolean      title_alignment = FALSE;
 
-  rows = gtk_tree_selection_get_selected_rows (selection, &model);
+  if (gtk_tree_selection_get_selected (selection, &model, &iter))
+    {
+      gtk_tree_model_get (model, &iter,
+                          COL_THEME_NAME, &theme,
+                          COL_THEME_RC, &filename, -1);
 
-  if (G_UNLIKELY (g_list_length (rows) == 0))
-    return;
+      /* set the theme name */
+      xfconf_channel_set_string (settings->priv->wm_channel, "/general/theme", theme);
+      g_free (theme);
 
-  gtk_tree_model_get_iter (model, &iter, rows->data);
-  gtk_tree_model_get (model, &iter, 0, &theme, -1);
+      /* check in the rc if the theme supports a custom button layout and/or
+       * title alignement */
+      rc = xfce_rc_simple_open (filename, TRUE);
+      g_free (filename);
 
-  xfconf_channel_set_string (settings->priv->wm_channel, "/general/theme", theme);
+      if (G_LIKELY (rc != NULL))
+        {
+          button_layout = !xfce_rc_has_entry (rc, "button_layout");
+          title_alignment = !xfce_rc_has_entry (rc, "title_alignment");
+          xfce_rc_close (rc);
+        }
+    }
 
-  g_free (theme);
-  g_list_foreach (rows, (GFunc) gtk_tree_path_free, NULL);
-  g_list_free (rows);
+  widget = glade_xml_get_widget (settings->priv->glade_xml, "button_layout_box");
+  gtk_widget_set_sensitive (widget, button_layout);
+
+  widget = glade_xml_get_widget (settings->priv->glade_xml, "title_align_box");
+  gtk_widget_set_sensitive (widget, title_alignment);
 }
 
 
@@ -1084,7 +1079,12 @@ xfwm_settings_active_frame_drag_data (GtkWidget        *widget,
 
   g_return_if_fail (XFWM_IS_SETTINGS (settings));
 
-  source = gtk_drag_get_source_widget (drag_context);
+  source = glade_xml_get_widget (settings->priv->glade_xml,
+#if GTK_CHECK_VERSION (2,14,0)
+                                 (const gchar *)gtk_selection_data_get_data (data));
+#else
+                                 (const gchar *) data->data);
+#endif
   parent = gtk_widget_get_parent (source);
 
   active_box = glade_xml_get_widget (settings->priv->glade_xml, "active-box");
@@ -1206,7 +1206,12 @@ xfwm_settings_hidden_frame_drag_data (GtkWidget        *widget,
 
   g_return_if_fail (XFWM_IS_SETTINGS (settings));
 
-  source = gtk_drag_get_source_widget (drag_context);
+  source = glade_xml_get_widget (settings->priv->glade_xml,
+#if GTK_CHECK_VERSION (2,14,0)
+                                 (const gchar *)gtk_selection_data_get_data (data));
+#else
+                                 (const gchar *) data->data);
+#endif
   parent = gtk_widget_get_parent (source);
 
   hidden_box = glade_xml_get_widget (settings->priv->glade_xml, "hidden-box");
@@ -1310,12 +1315,12 @@ xfwm_settings_title_button_drag_data (GtkWidget        *widget,
                                       GdkDragContext   *drag_context,
                                       GtkSelectionData *data,
                                       guint             info,
-                                      guint             time,
-                                      const gchar      *atom_name,
-                                      XfwmSettings     *settings)
+                                      guint             time)
 {
   gtk_widget_hide (widget);
-  gtk_selection_data_set (data, gdk_atom_intern (atom_name, FALSE), 8, NULL, 0);
+  gtk_selection_data_set (data, gdk_atom_intern ("_xfwm4_button_layout", FALSE), 8,
+                          (const guchar *)gtk_widget_get_name (widget),
+                          strlen (gtk_widget_get_name (widget)));
 }
 
 
@@ -1602,28 +1607,35 @@ xfwm_settings_click_to_focus_property_changed (XfconfChannel *channel,
 {
   GtkWidget *click_to_focus_radio;
   GtkWidget *focus_follows_mouse_radio;
+  GtkWidget *focus_delay_hbox;
 
   g_return_if_fail (XFWM_IS_SETTINGS (settings));
   g_return_if_fail (GLADE_IS_XML (settings->priv->glade_xml));
 
-  click_to_focus_radio = glade_xml_get_widget (settings->priv->glade_xml, 
+  click_to_focus_radio = glade_xml_get_widget (settings->priv->glade_xml,
                                                "click_to_focus_radio");
-  focus_follows_mouse_radio = glade_xml_get_widget (settings->priv->glade_xml, 
+  focus_follows_mouse_radio = glade_xml_get_widget (settings->priv->glade_xml,
                                                     "focus_follows_mouse_radio");
+  focus_delay_hbox = glade_xml_get_widget (settings->priv->glade_xml,
+                                           "focus_delay_hbox");
 
   if (G_UNLIKELY (G_VALUE_TYPE (value) != G_TYPE_BOOLEAN))
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (click_to_focus_radio), TRUE);
-  else 
+  else
     {
       if (g_value_get_boolean (value))
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (click_to_focus_radio), TRUE);
       else
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (focus_follows_mouse_radio), TRUE);
     }
+  gtk_widget_set_sensitive (GTK_WIDGET (focus_delay_hbox),
+                            gtk_toggle_button_get_active (
+                                  GTK_TOGGLE_BUTTON (focus_follows_mouse_radio)));
 }
 
 
 
+
 static void
 xfwm_settings_initialize_shortcuts (XfwmSettings *settings)
 {
@@ -1644,7 +1656,7 @@ xfwm_settings_initialize_shortcuts (XfwmSettings *settings)
     {
       gtk_list_store_append (GTK_LIST_STORE (model), &iter);
       gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                          SHORTCUTS_NAME_COLUMN, shortcut_values[i].name,
+                          SHORTCUTS_NAME_COLUMN, _(shortcut_values[i].name),
                           SHORTCUTS_FEATURE_COLUMN, shortcut_values[i].feature,
                           -1);
     }
@@ -1828,7 +1840,7 @@ xfwm_settings_shortcut_reset_clicked (GtkButton    *button,
 
   response = xfce_message_dialog (NULL, _("Reset to Defaults"), GTK_STOCK_DIALOG_QUESTION,
                                   _("Reset to Defaults"),
-                                  _("This will reset <b>all</b> shortcuts to their default "
+                                  _("This will reset all shortcuts to their default "
                                     "values. Do you really want to do this?"),
                                   GTK_STOCK_NO, GTK_RESPONSE_NO,
                                   GTK_STOCK_YES, GTK_RESPONSE_YES,
