@@ -1,4 +1,4 @@
-/*      $Id: events.c 28680 2008-11-09 11:46:07Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2008 Olivier Fourdan
+        xfwm4    - (c) 2002-2009 Olivier Fourdan
 
  */
 
@@ -50,6 +50,7 @@
 #include "client.h"
 #include "moveresize.h"
 #include "cycle.h"
+#include "placement.h"
 #include "stacking.h"
 #include "transients.h"
 #include "focus.h"
@@ -2025,6 +2026,12 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
             setNetFrameExtents (display_info, c->window, frameTop (c), frameLeft (c),
                                                          frameRight (c), frameBottom (c));
         }
+        else if (ev->message_type == display_info->atoms[NET_WM_FULLSCREEN_MONITORS])
+        {
+            TRACE ("client \"%s\" (0x%lx) has received a NET_WM_FULLSCREEN_MONITORS event", c->name, c->window);
+            clientSetFullscreenMonitor (c, (gint) ev->data.l[0], (gint) ev->data.l[1],
+                                           (gint) ev->data.l[2], (gint) ev->data.l[3]);
+        }
     }
     else
     {
@@ -2736,14 +2743,29 @@ size_changed_cb(GdkScreen *gscreen, gpointer data)
 static void
 monitors_changed_cb(GdkScreen *gscreen, gpointer data)
 {
+    ScreenInfo *screen_info;
+
     TRACE ("entering monitors_changed_cb");
 
+    screen_info = (ScreenInfo *) data;
+    g_return_if_fail (screen_info);
+
+    /* We have added/removed a monitor or even changed the layout,
+     * the cache for monitor position we use in our screen structure
+     * is not valid anymore and potentially refers to a monitor that
+     * was just removed, so invalidate it.
+     */
+    screen_info->cache_monitor.x = -1;
+    screen_info->cache_monitor.y = -1;
+    screen_info->cache_monitor.width = 0;
+    screen_info->cache_monitor.height = 0;
+
     /*
      * From the window manager point of view,
      * a XRand 1.2 monitor change is similar to
      * a screen size change.
      */
-    size_changed_cb(gscreen, data);
+    size_changed_cb (gscreen, data);
 }
 
 void
@@ -2756,15 +2778,15 @@ initGtkCallbacks (ScreenInfo *screen_info)
                           "button_press_event", GTK_SIGNAL_FUNC (show_popup_cb), (gpointer) NULL);
     g_signal_connect (GTK_OBJECT (myScreenGetGtkWidget (screen_info)), "client_event",
                       GTK_SIGNAL_FUNC (client_event_cb), (gpointer) (screen_info->display_info));
-    g_signal_connect(G_OBJECT(screen_info->gscr), "size-changed",
-                     G_CALLBACK(size_changed_cb),
-                     (gpointer) (screen_info));
+    g_signal_connect (G_OBJECT(screen_info->gscr), "size-changed",
+                      G_CALLBACK(size_changed_cb),
+                      (gpointer) (screen_info));
     if(gtk_major_version > 2 || (gtk_major_version == 2 && gtk_minor_version >= 13))
     {
         TRACE ("connect \"monitors-changed\" cb");
-        g_signal_connect(G_OBJECT(screen_info->gscr), "monitors-changed",
-                         G_CALLBACK(monitors_changed_cb),
-                         (gpointer) (screen_info));
+        g_signal_connect (G_OBJECT(screen_info->gscr), "monitors-changed",
+                          G_CALLBACK(monitors_changed_cb),
+                          (gpointer) (screen_info));
     }
 
     settings = gtk_settings_get_default ();
