@@ -1,4 +1,4 @@
-/*      $Id: moveresize.c 28365 2008-10-22 20:10:00Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2008 Olivier Fourdan
+        xfwm4    - (c) 2002-2009 Olivier Fourdan
 
  */
 
@@ -194,6 +194,13 @@ clientMovePointer (DisplayInfo *display_info, gint dx, gint dy, guint repeat)
     }
 }
 
+static gboolean
+clientKeyPressIsModifier (XEvent *xevent)
+{
+    int keysym = XLookupKeysym (&xevent->xkey, 0);
+    return (gboolean) IsModifierKey(keysym);
+}
+
 static void
 clientSetHandle(MoveResizeData *passdata, int handle)
 {
@@ -371,7 +378,6 @@ clientSnapPosition (Client * c, int prev_x, int prev_y)
     int best_delta_x, best_delta_y;
     int c_frame_x1, c_frame_x2, c_frame_y1, c_frame_y2;
     GdkRectangle rect;
-    gint monitor_nbr;
 
     g_return_if_fail (c != NULL);
     TRACE ("entering clientSnapPosition");
@@ -398,8 +404,7 @@ clientSnapPosition (Client * c, int prev_x, int prev_y)
     best_frame_x = frame_x;
     best_frame_y = frame_y;
 
-    monitor_nbr = find_monitor_at_point (screen_info->gscr, cx, cy);
-    gdk_screen_get_monitor_geometry (screen_info->gscr, monitor_nbr, &rect);
+    myScreenFindMonitorAtPoint (screen_info, cx, cy, &rect);
 
     disp_x = rect.x;
     disp_y = rect.y;
@@ -629,7 +634,7 @@ clientMoveEventFilter (XEvent * xevent, gpointer data)
         }
         else
         {
-            moving = FALSE;
+            moving = clientKeyPressIsModifier(xevent);
         }
     }
     else if (xevent->type == ButtonRelease)
@@ -1099,7 +1104,6 @@ clientResizeEventFilter (XEvent * xevent, gpointer data)
     int frame_top, frame_left, frame_right, frame_bottom;
     int move_top, move_bottom, move_left, move_right;
     int temp;
-    gint monitor_nbr;
     gint min_visible;
     gboolean resizing;
 
@@ -1142,8 +1146,7 @@ clientResizeEventFilter (XEvent * xevent, gpointer data)
             || (passdata->handle == CORNER_COUNT + SIDE_LEFT)) ?
         1 : 0;
 
-    monitor_nbr = find_monitor_at_point (screen_info->gscr, cx, cy);
-    gdk_screen_get_monitor_geometry (screen_info->gscr, monitor_nbr, &rect);
+    myScreenFindMonitorAtPoint (screen_info, cx, cy, &rect);
 
     disp_x = rect.x;
     disp_y = rect.y;
@@ -1255,7 +1258,7 @@ clientResizeEventFilter (XEvent * xevent, gpointer data)
         }
         else
         {
-            resizing = FALSE;
+            resizing = clientKeyPressIsModifier(xevent);
         }
     }
     else if (xevent->type == MotionNotify)
