@@ -1,4 +1,4 @@
-/*      $Id: mypixmap.c 23520 2006-10-25 19:33:41Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -12,7 +12,9 @@
 
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
-        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+        MA 02110-1301, USA.
+
 
         Original XPM load routines from gdk-pixbuf:
 
@@ -26,12 +28,12 @@
         XPM color substitution used by the themes to apply gtk+ colors.
 
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2006 Olivier Fourdan
+        xfwm4    - (c) 2002-2009 Olivier Fourdan
 
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <X11/Xlib.h>
@@ -318,7 +320,7 @@ out:
     return ret;
 }
 
-static gchar *
+static const gchar *
 search_color_symbol (gchar *symbol, xfwmColorSymbol *color_sym)
 {
     xfwmColorSymbol *i;
@@ -375,7 +377,7 @@ xpm_extract_color (const gchar *buffer, xfwmColorSymbol *color_sym)
         {
             if (color[0] == '\0')  /* incomplete colormap entry */
             {
-                return NULL;               
+                return NULL;
             }
             else  /* end of entry, still store the last color */
             {
@@ -430,7 +432,7 @@ xpm_extract_color (const gchar *buffer, xfwmColorSymbol *color_sym)
         }
         else if (key == 5)
         {
-            gchar *new_color = NULL;
+            const gchar *new_color = NULL;
             new_color = search_color_symbol (color, color_sym);
             if (new_color)
             {
@@ -731,7 +733,7 @@ xfwmPixmapRefreshPict (xfwmPixmap * pm)
 }
 
 static GdkPixbuf *
-xfwmPixmapCompose (GdkPixbuf *pixbuf, gchar * dir, gchar * file)
+xfwmPixmapCompose (GdkPixbuf *pixbuf, const gchar * dir, const gchar * file)
 {
     GdkPixbuf *alpha;
     gchar *filepng;
@@ -929,7 +931,7 @@ xfwmPixmapRenderGdkPixbuf (xfwmPixmap * pm, GdkPixbuf *pixbuf)
 }
 
 gboolean
-xfwmPixmapLoad (ScreenInfo * screen_info, xfwmPixmap * pm, gchar * dir, gchar * file, xfwmColorSymbol * cs)
+xfwmPixmapLoad (ScreenInfo * screen_info, xfwmPixmap * pm, const gchar * dir, const gchar * file, xfwmColorSymbol * cs)
 {
     gchar *filename;
     gchar *filexpm;
@@ -941,12 +943,7 @@ xfwmPixmapLoad (ScreenInfo * screen_info, xfwmPixmap * pm, gchar * dir, gchar *
     g_return_val_if_fail (dir != NULL, FALSE);
     g_return_val_if_fail (file != NULL, FALSE);
 
-    pm->screen_info = screen_info;
-    pm->pixmap = None;
-    pm->mask = None;
-    pm->width = 1;
-    pm->height = 1;
-
+    xfwmPixmapInit (screen_info, pm);
     /*
      * Always try to load the XPM first, using our own routine
      * that supports XPM color symbol susbstitution (used to
@@ -1052,6 +1049,15 @@ xfwmPixmapFree (xfwmPixmap * pm)
 #endif
 }
 
+gboolean
+xfwmPixmapNone (xfwmPixmap * pm)
+{
+    TRACE ("entering xfwmPixmapEmpty");
+
+    g_return_val_if_fail (pm != NULL, FALSE);
+    return (pm->pixmap == None);
+}
+
 static void
 xfwmPixmapFillRectangle (Display *dpy, int screen, Pixmap pm, Drawable d,
                          int x, int y, int width, int height)
