@@ -1,4 +1,4 @@
-/*      $Id: screen.h 27451 2008-08-14 22:36:35Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
 
 
         oroborus - (c) 2001 Ken Lynch
-        xfwm4    - (c) 2002-2008 Olivier Fourdan
+        xfwm4    - (c) 2002-2009 Olivier Fourdan
 
  */
 
@@ -30,6 +30,8 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <xfconf/xfconf.h>
+#include <libxfce4kbd-private/xfce-shortcuts-provider.h>
+
 
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
 #define SN_API_NOT_YET_FROZEN
@@ -46,6 +48,13 @@
 #include "client.h"
 #include "hints.h"
 
+#define MODIFIER_MASK           (ShiftMask | \
+                                 ControlMask | \
+                                 AltMask | \
+                                 MetaMask | \
+                                 SuperMask | \
+                                 HyperMask)
+
 #ifdef HAVE_COMPOSITOR
 struct _gaussian_conv {
     int     size;
@@ -106,6 +115,9 @@ struct _ScreenInfo
     int current_ws;
     int previous_ws;
 
+    /* Monitor search caching */
+    GdkRectangle cache_monitor;
+
     /* Workspace definitions */
     int workspace_count;
     gchar **workspace_names;
@@ -117,7 +129,9 @@ struct _ScreenInfo
 
     /* xfconf */
     XfconfChannel *xfwm4_channel;
-    XfconfChannel *keys_channel;
+
+    /* Shortcuts */
+    XfceShortcutsProvider *shortcuts_provider;
 
     /* Per screen parameters */
     XfwmParams *params;
@@ -179,23 +193,30 @@ GtkWidget               *myScreenGetGtkWidget                   (ScreenInfo *);
 GtkWidget               *myScreenGetGtkWidget                   (ScreenInfo *);
 GdkWindow               *myScreenGetGdkWindow                   (ScreenInfo *);
 gboolean                 myScreenGrabKeyboard                   (ScreenInfo *,
-                                                                 Time);
+                                                                 guint32);
 gboolean                 myScreenGrabPointer                    (ScreenInfo *,
                                                                  unsigned int,
                                                                  Cursor,
-                                                                 Time);
+                                                                 guint32);
 gboolean                 myScreenChangeGrabPointer              (ScreenInfo *,
                                                                  unsigned int,
                                                                  Cursor,
-                                                                 Time);
+                                                                 guint32);
 unsigned int             myScreenUngrabKeyboard                 (ScreenInfo *,
-                                                                 Time);
+                                                                 guint32);
 unsigned int             myScreenUngrabPointer                  (ScreenInfo *,
-                                                                 Time);
+                                                                 guint32);
 void                     myScreenGrabKeys                       (ScreenInfo *);
 void                     myScreenUngrabKeys                     (ScreenInfo *);
+int                      myScreenGetKeyPressed                  (ScreenInfo *,
+                                                                 XKeyEvent *);
 Client                  *myScreenGetClientFromWindow            (ScreenInfo *,
                                                                  Window,
                                                                  unsigned short);
+void                     myScreenInvalidateMonitorCache         (ScreenInfo *);
+void                     myScreenFindMonitorAtPoint             (ScreenInfo *,
+                                                                 gint,
+                                                                 gint,
+                                                                 GdkRectangle *);
 
 #endif /* INC_SCREEN_H */
