@@ -1,4 +1,4 @@
-/*      $Id: tabwin.c 27004 2008-06-01 10:25:24Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
         MA 02110-1301, USA.
 
 
-        xfwm4    - (c) 2002-2008 Olivier Fourdan
+        xfwm4    - (c) 2002-2009 Olivier Fourdan
 
  */
 
@@ -67,10 +67,14 @@ get_color (GtkWidget * win, GtkStateType state_type)
 static gboolean
 paint_selected (GtkWidget * w, GdkEventExpose * event, gpointer data)
 {
-    gtk_paint_box (w->style, w->window,
+    gtk_draw_flat_box (w->style, w->window,
         GTK_STATE_SELECTED,
-        GTK_SHADOW_IN,
-        NULL, w, "box",
+        GTK_SHADOW_NONE,
+        w->allocation.x - WIN_ICON_BORDER,
+        w->allocation.y - WIN_ICON_BORDER,
+        w->allocation.width + 2 * WIN_ICON_BORDER,
+        w->allocation.height + 2 * WIN_ICON_BORDER);
+    gtk_draw_focus (w->style, w->window,
         w->allocation.x - WIN_ICON_BORDER,
         w->allocation.y - WIN_ICON_BORDER,
         w->allocation.width + 2 * WIN_ICON_BORDER,
@@ -197,7 +201,6 @@ createWindowlist (GdkScreen * scr, Client * current, Client * new, unsigned int
     unsigned int grid_rows;
     int i, packpos;
     int msx, msy;
-    gint monitor;
 
     g_return_val_if_fail (current != NULL, NULL);
 
@@ -213,8 +216,7 @@ createWindowlist (GdkScreen * scr, Client * current, Client * new, unsigned int
     g_return_val_if_fail (n_clients > 0, NULL);
 
     getMouseXY (screen_info, screen_info->xroot, &msx, &msy);
-    monitor = find_monitor_at_point (scr, msx, msy);
-    gdk_screen_get_monitor_geometry (scr, monitor, &monitor_sz);
+    myScreenFindMonitorAtPoint (screen_info, msx, msy, &monitor_sz);
 
     /* add the width of the border on each side */
     grid_cols = (monitor_sz.width / (WIN_ICON_SIZE + 2 * WIN_ICON_BORDER)) * 0.75;
